@@ -216,7 +216,7 @@ void TransitionWidget::grabBackground(QPixmap &pixmap, QWidget *widget, QRect &r
         widgets.append(parent);
 
         // stop at topLevel
-        if (parent->isTopLevel() || parent->autoFillBackground()) {
+        if (parent->isWindow() || parent->autoFillBackground()) {
             break;
         }
     }
@@ -235,7 +235,7 @@ void TransitionWidget::grabBackground(QPixmap &pixmap, QWidget *widget, QRect &r
         p.fillRect(pixmap.rect(), backgroundBrush);
     }
 
-    if (parent->isTopLevel() && parent->testAttribute(Qt::WA_StyledBackground)) {
+    if (parent->isWindow() && parent->testAttribute(Qt::WA_StyledBackground)) {
         QStyleOption option;
         option.initFrom(parent);
         option.rect = rect;
